#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/oracle/mungers'

newparam(:name) do
  include EasyType
  include EasyType::Validators::Name
  include Puppet_X::EnterpriseModules::Oracle::Mungers::LeaveSidRestToUppercase

  desc <<-EOD
    The object and name combination you want to manage. Including an appended SID.

        ora_object_grant { 'SCOTT->sys.dbms_aqin@SID':
          ...
        }

    The SID is optional. When you don't specify an SID, Puppet will take the first ASM instance
    from the `/etc/oratab` file and use that as the SID. We recoomend you **always** use a full qualified
    name (e.g. a name including the SID).

  EOD

  isnamevar
  data_type("String[1]")

  to_translate_to_resource do |raw_resource|
    sid        = raw_resource.column_data('SID')
    owner      = raw_resource.column_data('OWNER').upcase
    table_name = raw_resource.column_data('TABLE_NAME').upcase
    grantee    = raw_resource.column_data('GRANTEE').upcase
    "#{grantee}->#{owner}.#{table_name}@#{sid}"
  end
end
