#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:cpu_per_session, :parent => Puppet::Parameter::OracleProfileProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
    Allows you set the cpu_per_session value in a profile.

    Maximum CPU time per session (100ths of a second)

    cpu_per_session <value | UNLIMITED | DEFAULT>

    Here is an example on how to use this:

        ora_profile { 'DEFAULT@sid':
          ...
          cpu_per_session => 'UNLIMITED',
          ...
        }

  EOD

  validate do | value|
    return if value =~ /unlimited/i
    return if value =~ /default/i
    super(value)
  end

  data_type("Optional[Variant[Enum['DEFAULT','UNLIMITED'], Integer]]")
end
