#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:ensure) do
  include EasyType

  desc <<-EOD
    absent, present or updated.

    when present is specified, it will just check if the primary key record is available. If it is,
    nothing will be done. When you specify 'updated', puppet will ensure the data is as specified
    in the data property of the puppet definition.

  EOD

  data_type("Enum['present', 'absent', 'updated']")

  newvalue(:present) do
    if @resource.provider && @resource.provider.respond_to?(:create)
      @resource.provider.create
    else
      @resource.create
    end
    nil # return nil so the event is autogenerated
  end

  newvalue(:updated) do
    if @resource.provider && @resource.provider.respond_to?(:create)
      @resource.provider.create
    else
      @resource.create
    end
    nil # return nil so the event is autogenerated
  end

  newvalue(:absent) do
    if @resource.provider && @resource.provider.respond_to?(:destroy)
      @resource.provider.destroy
    else
      @resource.destroy
    end
    nil # return nil so the event is autogenerated
  end

  def insync?(is)
    if ['present', 'updated'].include?(should.to_s) && is.to_s == 'present'
      true
    else
      is == should
    end
  end
end
