#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:job_class) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  desc <<-EOD
    Specifies the class for the job.

    Here is an example on how to use this:

        ora_scheduler_job{ 'me.my_job@sid':
          ...
          job_class => 'DEFAULT_JOB_CLASS',
          ...
        }

    Default value: 'DEFAULT_JOB_CLASS'

  EOD

  defaultto 'DEFAULT_JOB_CLASS'

  data_type("Optional[String[1]]")

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('JOB_CLASS')
  end

  on_modify do
    statement = template('ora_config/ora_scheduler_job/modify_quoted_attribute.sql.erb', binding)
    sql statement, {:sid => resource.sid}
  end

end
