#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:max_runs) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  desc <<-EOD
    The maximum number of runs for the job.

    Here is an example on how to use this:

        ora_scheduler_job{ 'me.my_job@sid':
          ...
          max_runs => 5,
          ...
        }

    Puppet doesn't provide a default value.

  EOD

  data_type("Optional[Integer]")

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('MAX_RUNS').to_i
  end

  on_modify do
    if resource.max_runs == '' or resource.max_runs.nil?
      statement = "begin dbms_scheduler.set_attribute_null(name => '#{resource.owner}.#{resource.job_name}', attribute => 'MAX_RUNS'); end;\n/\n"
    else
      statement = template('ora_config/ora_scheduler_job/modify_unquoted_attribute.sql.erb', binding)
    end
    sql statement, {:sid => resource.sid}
  end

end
