#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:state) do
  include Puppet_X::EnterpriseModules::Oracle::ServiceProperty
  include Puppet_X::EnterpriseModules::Oracle::Commands

  desc <<-EOD
    When a service is disabled Oracle Clusterware will not automatically start, failover or restart
    the service for maintenance purposes.

    Here is an example on how to use this:

        ora_service{'my_service':
          ...
          state => 'DISABLED',
          ...
        }

    Puppet provides no default value. But Oracle might, depending on your version.

    This is a cluster only property. On single node database this property will be ignored. If you use it,
    Puppet will issue a warning.

  EOD

  column_name 'Service is'
  newvalues(:ENABLED, :DISABLED, :enabled, :disabled)
  data_type("Optional[Enum['ENABLED', 'DISABLED', 'enabled', 'disabled']]")

  def insync?(_is)
    return true unless cluster?
    provider.state.casecmp(resource.state.to_s) != 0 ? false : true
  end

  on_apply do
    # Do nothing directly, but after tyhe service has been created, disable it if specified so.
  end

  after_create do
    srvctl("disable service -d #{db_for(sid)} -s #{resource.service_name}", { :sid => sid }) if cluster? and state_value == 'disable'
  end

  on_modify do
    if cluster?
      srvctl("#{state_value} service -d #{db_for(sid)} -s #{resource.service_name}", { :sid => sid_for(sid) })
    else
      nil
    end
  end

  def state_value
    case value.to_s.downcase
      when 'enabled'
      then 'enable'
      else 'disable'
    end
  end
end
