#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:next) do
  include EasyType
  include TablespaceType
  include Puppet_X::EnterpriseModules::Oracle::Access
  include Puppet_X::EnterpriseModules::Oracle::DatafileProperty
  include EasyType::Mungers::Size

  desc <<-EOD
    Size of the next autoextent.
  EOD

  # Issue in Puppet causes external types to not always 
  # be resolved. Therefore we include the basic variant
  # data_type("Optional[Easy_type::Size]")
  data_type("Optional[Variant[Pattern[/^([0-9]*[k|K|m|M|g|G|t|T]|unlimited|UNLIMITED)$/], Integer]]")

  to_translate_to_resource do |raw_resource|
    block_size = raw_resource.column_data('BLOCK_SIZE').to_i
    increment = raw_resource.column_data('INCREMENT_BY').to_i
    increment * block_size
  end

  on_create do
    if resource[:autoextend].to_s == 'on'
      # only add next clause to command if there is only one datafile
      "next #{value}" unless ( df_array_size(provider.datafile) > 1 or desired_num_datafiles > 1 )
    else
      Puppet.warning "#{path}: property next changed on ora_tablespace[#{resource[:name]}], but autoextend is off. "
      nil
    end
  end

end
