#!/opt/puppetlabs/puppet/bin/ruby
#
#
# See the file "LICENSE" for the full license governing this code.
#
#
require 'json'
require 'puppet'

install_dir = ENV['PT__installdir']
Puppet[:codedir] = install_dir
Puppet[:vardir]  = '/tmp'

if install_dir
  #
  # Use loadpath specfied in the params
  #
  $LOAD_PATH << "#{install_dir}/easy_type/lib"
  $LOAD_PATH << "#{install_dir}/ora_config/lib"
else
  begin
    Puppet.initialize_settings
  rescue Puppet::DevError
    # When run in Rspec, this is called multiple times
  end
end
require 'easy_type'
require 'puppet_x/enterprisemodules/oracle/access'
require 'puppet_x/enterprisemodules/oracle/settings'

include ::Puppet_X::EnterpriseModules::Oracle::Settings # Needed for default_database_sid

params = JSON.parse(STDIN.read)
sid      = params.fetch('sid') { default_database_sid}
username = params['username']
password = params['password']
sql      = params['sql']
raw      = params.fetch('raw') { true }

begin
  result = {}
  include ::Puppet_X::EnterpriseModules::Oracle::Access
  options = {:sid => sid}
  options.merge!(:parse => false ) if raw
  options.merge!(:username => username) if username
  options.merge!(:password => password) if password
  results = sql(sql, options)
  if raw
    puts results
  else
    puts({ results: results }.to_json)
  end
  exit 0
rescue Puppet::Error => e
  puts({ status: 'failure', error: e.message }.to_json)
  exit 1
end
